"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.automockEnums = automockEnums;
exports.automockScalars = automockScalars;
exports.defaultAutomocks = exports.scalarMocks = void 0;

var _graphql = require("graphql");

var _list = require("./list");

var _relay = require("./relay");

var random = _interopRequireWildcard(require("./random"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function automockEnums(parentType, field) {
  const nullableType = (0, _graphql.getNullableType)(field.type);

  if (!(nullableType instanceof _graphql.GraphQLEnumType)) {
    return;
  }

  const values = nullableType.getValues().map(value => value.value);
  return () => values[random.getInt(0, values.length - 1)];
}

const scalarMocks = {
  Boolean: () => random.getBoolean(),
  ID: () => random.getUUID(),
  Int: () => random.getInt(-100, 100),
  Float: () => random.getFloat(-100, 100),
  String: () => random.getString()
};
exports.scalarMocks = scalarMocks;

function automockScalars(scalarMocks) {
  return (parentType, field) => {
    const nullableType = (0, _graphql.getNullableType)(field.type);
    const scalarMock = scalarMocks[nullableType.name];

    if (scalarMock) {
      return scalarMock;
    }
  };
}

const defaultAutomocks = [automockScalars(scalarMocks), automockEnums, _list.automockLists, _relay.automockRelay];
exports.defaultAutomocks = defaultAutomocks;
//# sourceMappingURL=automock.js.map